;; Generated package description from spinner.el  -*- no-byte-compile: t -*-
(define-package "spinner" "1.7.4.0.20210701.182039" "Add spinners and progress-bars to the mode-line for ongoing operations" '((emacs "24.3")) :authors '(("Artur Malabarba" . "emacs@endlessparentheses.com")) :maintainer '("Artur Malabarba" . "emacs@endlessparentheses.com") :keywords '("processes" "mode-line") :url "https://github.com/Malabarba/spinner.el")
